@@ -203,6 +203,9 @@ class PlatformBase(  # pylint: disable=too-many-instance-attributes,too-many-pub
                 elif "nobuild" in targets and opts.get("type") != "framework":
                     self.packages[name]["optional"] = True
 
+    def configure_debug_options(self, initial_debug_options, ide_data):
+        raise NotImplementedError
+
     def get_lib_storages(self):
         storages = {}
         for opts in (self.frameworks or {}).values():
